\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{tudobrief}[09/04/2008 Corporate Identity Brief fuer den LS2 Version 2.0]

% Laden der Oberklasse
\LoadClass{letter}

\def\babellanguage{ngerman}

% Deklaration von Optionen
\DeclareOption{ngerman}{
  \setgermanlabels
  \def\babellanguage{ngerman}
}
\DeclareOption{british}{
  \setenglishlabels
  \def\babellanguage{british}
}
\DeclareOption{american}{
  \setenglishlabels
  \def\babellanguage{american}
}

%% Sprache
% Deutsch
\def\setgermanlabels{
  \def\facultytext{Fakult\"at f\"ur Informatik}%
  \def\chairtext{~}%
  \def\telefonname{Telefon}
  \def\telefaxname{Telefax}
  \def\emailname{E-Mail}
  \def\wwwname{WWW}
  \def\raumname{Raum}
  \def\datumname{Datum}
  \def\seitenname{Seite}
  \address{Fakult{\"a}t f{\"u}r Informatik, Lehrstuhl 11\\Technische Universit{\"a}t Dortmund, 44221 Dortmund}
  }
% Englisch
\def\setenglishlabels{
  \def\facultytext{Department of\\Computer Science}%
  \def\chairtext{}%Efficient Algorithms and Complexity Theory}%
  \def\telefonname{Phone}
  \def\telefaxname{Fax}
  \def\emailname{Email}
  \def\wwwname{WWW}
  \def\raumname{Room}
  \def\datumname{Date}
  \def\seitenname{Page}
  \address{Department of Computer Science 11\\Technische Universit{\"a}t Dortmund $\cdot$ 44221 Dortmund $\cdot$ Germany}
  }

\DeclareOption{nogfx}{
  \PassOptionsToPackage{nogfx}{tu-corpid}
}

%% Ausfuehrung von Optionen
\setgermanlabels
\ProcessOptions*

% Initialisierungsteil, Laden von Paketen
\RequirePackage[\babellanguage]{babel}
\RequirePackage{ifthen}
\RequirePackage{tu-corpid}

%% Schrift und Zeilenabstande
\renewcommand{\familydefault}{cmss}
\renewcommand{\normalsize}{\fontsize{11pt}{15pt}\selectfont}

%% Kopfzeile im rechten Rand
\setoddheadtext{%
  \parbox[t]{44mm}{
    \fontsize{12pt}{13pt}\selectfont%
    \facultytext\\[2pt]%
    \ifx\@empty\chairtext     \else {{\chairtext}}\\ \fi%
    \fontsize{7.5pt}{10pt}\selectfont%
    \ifx\@empty\theheadername \\[5mm] \else {\textbf{\theheadername}}\\[5mm] \fi%
    \ifx\@empty\derverfasser  \else {{\derverfasser}}\\ \fi%
    %% Entweder "Strae, Raum" oder nur "Strae" oder nur "Raum", je nachdem, welche Daten angegeben werden.
    \ifx\@empty\diestrasse{\ifx\@empty\derraum       \else {\raumname} {\derraum}\\ \fi}%       
	\else {\diestrasse\ifx\@empty\derraum       \else {, \raumname} {\derraum} \fi\\} \fi%
    \ifx\@empty\diestadt      \else {\diestadt}\\ \fi%
    \ifx\@empty\telefonnummer \else {\telefonname}: {\telefonnummer}\\ \fi%
    \ifx\@empty\faxnummer     \else {\telefaxname}: {\faxnummer}\\ \fi%
    \ifx\@empty\emailadresse  \else {\emailadresse}\\ \fi%
    \ifx\@empty\dieurl        \else {\dieurl}\\ \fi%
    \ifx\@empty\@date         \else {\@date}\\ \fi%
  }%
}%

%% Fusszeile
\setoddfoottext{%
	\fontsize{7.5pt}{10pt}\selectfont%
	%Otto-Hahn-Stra{\ss}e 14 \\ 44227 Dortmund \\ (Eichlinghofen)\\[5mm]%
	\centerline{\seitenname\ \arabic{page}}%
}%
\setoddfootinfo{}

%% Eroeffnung und Briefkopf
%\def\opening[#1]#2{%
\renewcommand{\opening}[2][]{%
  \thispagestyle{firstpage}%
  \raisebox{0cm}[0cm][0cm]{%
  \begin{minipage}[t]{12cm}%
%    \ifx\@empty\theheadername \else {\normalsize\raisebox{4pt}[45pt][0pt]{\parbox[b]{12cm}{\theheadername}}}\\\fi%
    \fontsize{7pt}{8pt}\selectfont \fromaddress\par%
    \vspace{6mm}%
    \normalsize%
    \toname\\\toaddress%
  \end{minipage}%
  }
    \ifthenelse{\equal{#1}{}}{%
      \par%
      \vspace{53.8mm}%
      #2 \par\nobreak%
      %\raggedright
    }{%
      \par%
      \vspace{64.8mm}%
      {\bf #1}\par\nobreak%
      \par%
      \vspace{6mm}%
      #2 \par\nobreak%
      %\raggedright
    }%
}

\def\closing#1{%
  \stopbreaks%
  \noindent\par%
  #1\vspace{2cm}\\%                                
  \ifx\@empty\fromsig%
  \fromname%
  \else \fromsig \fi\strut%
  \vfill%
}


%%% Befehle zum Setzen von Feldern

%% Briefkopf
\newcommand{\headername}[1]{\def\theheadername{#1}}
\newcommand{\strasse}[1]{\def\diestrasse{#1}}
\newcommand{\stadt}[1]{\def\diestadt{#1}}
\newcommand{\telefon}[1]{\def\telefonnummer{#1}}
\newcommand{\fax}[1]{\def\faxnummer{#1}}
\newcommand{\verfasser}[1]{\def\derverfasser{#1}}
\newcommand{\email}[1]{\def\emailadresse{#1}}
\newcommand{\raum}[1]{\def\derraum{#1}}
\newcommand{\www}[1]{\def\dieurl{#1}}
\newcommand{\meinname}[1]{\verfasser{#1}\headername{#1}\signature{#1}}
\newcommand{\clearlabels}{
  \headername{}
  \verfasser{}
  \email{}
  \telefon{}
  \signature{}
  \fax{}
  \raum{}
  \www{}
}

\newcommand{\hier}{{\bf{}-~hier~-}}

% Defaultwerte setzen
\clearlabels
%\def\theheadername{Prof. Dr. Ingo Wegener}
\fax{0231/755-7740}
\strasse{Otto-Hahn-Str.\ 14}
\stadt{44221 Dortmund}
%\date{March 31, 2009}

\@input{address.tex}

\endinput
